searchData={"items":[{"type":"module","doc":"Elixir wrapper for the Signal Protocol library.\nProvides a clean, idiomatic interface for secure messaging.","title":"LibsignalProtocol","ref":"LibsignalProtocol.html"},{"type":"function","doc":"Creates a new session for a recipient.\nReturns `{:ok, session}` on success or `{:error, reason}` on failure.","title":"LibsignalProtocol.create_session/1","ref":"LibsignalProtocol.html#create_session/1"},{"type":"function","doc":"Decrypts a message using the given session.\nReturns `{:ok, decrypted_message}` on success or `{:error, reason}` on failure.","title":"LibsignalProtocol.decrypt_message/2","ref":"LibsignalProtocol.html#decrypt_message/2"},{"type":"function","doc":"Encrypts a message using the given session.\nReturns `{:ok, encrypted_message}` on success or `{:error, reason}` on failure.","title":"LibsignalProtocol.encrypt_message/2","ref":"LibsignalProtocol.html#encrypt_message/2"},{"type":"function","doc":"Initializes the Signal Protocol library.\nReturns `:ok` on success or `{:error, reason}` on failure.","title":"LibsignalProtocol.init/0","ref":"LibsignalProtocol.html#init/0"},{"type":"module","doc":"Signal Protocol implementation for Elixir.\n\nThis module provides a high-level interface to the Signal Protocol,\nimplementing end-to-end encryption for secure messaging.","title":"SignalProtocol","ref":"SignalProtocol.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"SignalProtocol.child_spec/1","ref":"SignalProtocol.html#child_spec/1"},{"type":"function","doc":"Creates a new session with the given local and remote identity keys.\n\nReturns `{:ok, session}` on success, where `session` is an opaque reference\nto the session state.","title":"SignalProtocol.create_session/2","ref":"SignalProtocol.html#create_session/2"},{"type":"function","doc":"Decrypts a message using the given session.\n\nReturns `{:ok, plaintext}` on success.","title":"SignalProtocol.decrypt_message/2","ref":"SignalProtocol.html#decrypt_message/2"},{"type":"function","doc":"Encrypts a message using the given session.\n\nReturns `{:ok, ciphertext}` on success.","title":"SignalProtocol.encrypt_message/2","ref":"SignalProtocol.html#encrypt_message/2"},{"type":"function","doc":"Generates a new identity key pair.\n\nReturns `{:ok, {public_key, signature}}` on success.","title":"SignalProtocol.generate_identity_key_pair/0","ref":"SignalProtocol.html#generate_identity_key_pair/0"},{"type":"function","doc":"Generates a new pre-key with the given ID.\n\nReturns `{:ok, {key_id, public_key}}` on success.","title":"SignalProtocol.generate_pre_key/1","ref":"SignalProtocol.html#generate_pre_key/1"},{"type":"function","doc":"Generates a new signed pre-key with the given ID, signed by the identity key.\n\nReturns `{:ok, {key_id, public_key, signature}}` on success.","title":"SignalProtocol.generate_signed_pre_key/2","ref":"SignalProtocol.html#generate_signed_pre_key/2"},{"type":"function","doc":"Processes a pre-key bundle to establish a session.\n\nReturns `:ok` on success.","title":"SignalProtocol.process_pre_key_bundle/2","ref":"SignalProtocol.html#process_pre_key_bundle/2"},{"type":"function","doc":"Starts a new Signal Protocol session manager.","title":"SignalProtocol.start_link/1","ref":"SignalProtocol.html#start_link/1"},{"type":"function","doc":"* `:name` - The name to register the process under (optional)","title":"Options - SignalProtocol.start_link/1","ref":"SignalProtocol.html#start_link/1-options"},{"type":"module","doc":"Handles the creation and processing of pre-key bundles for the Signal Protocol.\n\nPre-key bundles are used to establish initial sessions between users\nin an asynchronous manner.","title":"SignalProtocol.PreKeyBundle","ref":"SignalProtocol.PreKeyBundle.html"},{"type":"function","doc":"Creates a new pre-key bundle with the given components.","title":"SignalProtocol.PreKeyBundle.create/5","ref":"SignalProtocol.PreKeyBundle.html#create/5"},{"type":"function","doc":"* `registration_id` - The registration ID of the user\n  * `identity_key` - The user's identity key\n  * `pre_key` - A pre-key tuple `{key_id, public_key}`\n  * `signed_pre_key` - A signed pre-key tuple `{key_id, public_key, signature}`\n  * `base_key` - The base key for the X3DH key agreement\n\nReturns `{:ok, bundle}` on success, where `bundle` is a binary containing\nthe serialized pre-key bundle.","title":"Parameters - SignalProtocol.PreKeyBundle.create/5","ref":"SignalProtocol.PreKeyBundle.html#create/5-parameters"},{"type":"function","doc":"Parses a pre-key bundle from its binary representation.\n\nReturns `{:ok, bundle}` on success, where `bundle` is a map containing\nthe bundle components.","title":"SignalProtocol.PreKeyBundle.parse/1","ref":"SignalProtocol.PreKeyBundle.html#parse/1"},{"type":"function","doc":"Verifies the signature of a pre-key bundle.\n\nReturns `:ok` if the signature is valid, `{:error, reason}` otherwise.","title":"SignalProtocol.PreKeyBundle.verify_signature/1","ref":"SignalProtocol.PreKeyBundle.html#verify_signature/1"},{"type":"module","doc":"Handles Signal Protocol sessions for secure messaging.\n\nThis module provides a high-level interface for managing Signal Protocol\nsessions, including session creation, message encryption, and decryption.","title":"SignalProtocol.Session","ref":"SignalProtocol.Session.html"},{"type":"function","doc":"Creates a new session with the given local and remote identity keys.","title":"SignalProtocol.Session.create/2","ref":"SignalProtocol.Session.html#create/2"},{"type":"function","doc":"* `local_identity_key` - The local user's identity key\n  * `remote_identity_key` - The remote user's identity key\n\nReturns `{:ok, session}` on success, where `session` is a reference to\nthe session state.","title":"Parameters - SignalProtocol.Session.create/2","ref":"SignalProtocol.Session.html#create/2-parameters"},{"type":"function","doc":"Creates a new session and processes a pre-key bundle in one step.","title":"SignalProtocol.Session.create_and_process_bundle/3","ref":"SignalProtocol.Session.html#create_and_process_bundle/3"},{"type":"function","doc":"* `local_identity_key` - The local user's identity key\n  * `remote_identity_key` - The remote user's identity key\n  * `bundle` - The pre-key bundle to process\n\nReturns `{:ok, session}` on success.","title":"Parameters - SignalProtocol.Session.create_and_process_bundle/3","ref":"SignalProtocol.Session.html#create_and_process_bundle/3-parameters"},{"type":"function","doc":"Decrypts a message using the given session.","title":"SignalProtocol.Session.decrypt_message/2","ref":"SignalProtocol.Session.html#decrypt_message/2"},{"type":"function","doc":"* `session` - The session reference\n  * `ciphertext` - The encrypted message to decrypt\n\nReturns `{:ok, plaintext}` on success.","title":"Parameters - SignalProtocol.Session.decrypt_message/2","ref":"SignalProtocol.Session.html#decrypt_message/2-parameters"},{"type":"function","doc":"Encrypts a message using the given session.","title":"SignalProtocol.Session.encrypt_message/2","ref":"SignalProtocol.Session.html#encrypt_message/2"},{"type":"function","doc":"* `session` - The session reference\n  * `message` - The message to encrypt\n\nReturns `{:ok, ciphertext}` on success.","title":"Parameters - SignalProtocol.Session.encrypt_message/2","ref":"SignalProtocol.Session.html#encrypt_message/2-parameters"},{"type":"function","doc":"Processes a pre-key bundle to establish a session.","title":"SignalProtocol.Session.process_pre_key_bundle/2","ref":"SignalProtocol.Session.html#process_pre_key_bundle/2"},{"type":"function","doc":"* `session` - The session reference\n  * `bundle` - The pre-key bundle to process\n\nReturns `:ok` on success.","title":"Parameters - SignalProtocol.Session.process_pre_key_bundle/2","ref":"SignalProtocol.Session.html#process_pre_key_bundle/2-parameters"},{"type":"function","doc":"Receives a message through a session, handling decryption.","title":"SignalProtocol.Session.receive_message/2","ref":"SignalProtocol.Session.html#receive_message/2"},{"type":"function","doc":"* `session` - The session reference\n  * `ciphertext` - The encrypted message to receive\n\nReturns `{:ok, plaintext}` on success.","title":"Parameters - SignalProtocol.Session.receive_message/2","ref":"SignalProtocol.Session.html#receive_message/2-parameters"},{"type":"function","doc":"Sends a message through a session, handling encryption.","title":"SignalProtocol.Session.send_message/2","ref":"SignalProtocol.Session.html#send_message/2"},{"type":"function","doc":"* `session` - The session reference\n  * `message` - The message to send\n\nReturns `{:ok, ciphertext}` on success.","title":"Parameters - SignalProtocol.Session.send_message/2","ref":"SignalProtocol.Session.html#send_message/2-parameters"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}